if QUASAR ~= nil then
	if QUASAR.subversion ~= "LITE" then
		print("FOV Toy is meant to run under the DefaultUI! It was not loaded.")
		return
	end
end

local function createSlider(inputTable)
	
	if inputTable ~= nil then
		assert(type(inputTable) == "table", "bad argument to qgen.hslider; expected a table, got " .. type(inputTable))
	end
	
	local baseTable = {
		size = "200x",
		border = "NO",
		expand = "YES",
		xmin = 1,
		xmax = 100,
		dx = 10,
		posx = 1,
	}
	
	for k, v in pairs(inputTable) do
		baseTable[k] = v
	end
	
	baseTable.scrollbar = "HORIZONTAL"
	
	return iup.canvas(baseTable)
	
end

local createFOVslider = function()
	local diag
	local negate = 1
	local curValue = iup.label {
		title = "000000",
	}

	local slider = createSlider {
		posx = Game.GetCVar("fov"),
		xmax = 360,
		scroll_cb = function(self, x, y)
			curValue.title = tostring(y * negate)
			gkinterface.SetFOV(y * negate)
		end,
	}
	
	diag = iup.dialog {
		topmost = "YES",
		bgcolor = "0 0 0",
		iup.vbox {
			margin = 6,
			iup.label {
				title = "FOV slider toy!",
			},
			slider,
			iup.hbox {
				iup.label {
					title = "current FOV is: ",
				},
				curValue,
			},
			iup.hbox {
				iup.stationtoggle {
					title = " set as negative FOV",
					action = function(self)
						if self.value == "ON" then
							negate = -1
						else
							negate = 1
						end
					end,
				},
				iup.fill { },
				iup.stationbutton {
					title = "Save",
					action = function()
						Game.SetCVar("fov", tostring(slider.posx * negate))
					end,
				},
				iup.stationbutton {
					title = "Default",
					action = function()
						slider.posx = 60
						curValue.title = "60"
						gkinterface.SetFOV(60)
					end,
				},
			},
		},
	}
	
	diag:show()
	
	curValue.title = Game.GetCVar("fov")
	
end

if QUASAR ~= nil then
	RegisterMod {
		main = "FOV Toy",
		version = "v1.0 b001",
		action = function() createFOVslider() end,
		about = [[Mod Author: Luxen De'Mark
This mod allows a pilot to visually adjust their FOV.
]],}
end

RegisterUserCommand("fovtoy", function() createFOVslider() end)